import { NextRequest, NextResponse } from "next/server";

export async function POST(req: NextRequest) {
  try {
    const { title, type, apiKey } = await req.json();
    console.log("Received request:", { title, type, apiKey });

    if (!apiKey) {
      console.error("❌ Missing OpenAI API Key");
      return NextResponse.json({ error: "Missing OpenAI API Key" }, { status: 400 });
    }

    // 📝 Define word count for each article type
const prompts: Record<string, number> = {
    "Human Written": 1000,
    "SEO Optimized": 800,
    "User Analyzed": 200,
    "AI-Assisted": 600,
    "Engaging & Readable": 500,
    "Short Content": 100,
  };
  
      const prompt = `With title: ${title} maintining ${prompts[type]} words, I want you to act as a highly proficient content writer specialized in SEO. Follow these steps:
  
              2. **Then write the full article**. 
              3. Bold all headings using Markdown.
              4. Write at least 14 headings and subheadings (including H1, H2, H3, H4). 
              5. SEO-optimized, human-written article in English, ensuring it’s unique and engaging. 
              
              The content should:
              - Be written in your own words (no copying or pasting).
              - Maintain perplexity and burstiness while being specific and contextually accurate.
              - Be detailed but conversational (use personal pronouns, informal tone, simple language).
              - Include rhetorical questions, metaphors, and analogies to engage the reader.
              - Use active voice and keep sentences brief.
              
              End with a conclusion and 5 unique FAQs.
              
              **Formatting Details:**
              - Bold the title and all headings.
              Ensure the article is pragmatism-free.
  Distribute the keyword well in the article and in the h2 and h3 titles
  Do not over emphasize (too much adding of the keyword)
  
  `;
    console.log("Generated prompt:", prompt);

    // 🌍 Call OpenAI API
    const response = await fetch("https://api.openai.com/v1/chat/completions", {
      method: "POST",
      headers: {
        
        "Content-Type": "application/json",
        "Authorization": `Bearer ${apiKey}`,
      },
      body: JSON.stringify({
        model: "gpt-4o-mini",
        messages: [
            { role: "user", content: prompt },  // Using the prompt here as a message from the user
          ],
          temperature: 0.7,  // Adjust temperature for creativity
        max_tokens: 1000,
      }),
    });
    console.log("Generated prompt:", response.body);


    if (!response.ok) {
      console.error("❌ Error calling OpenAI API:", response.status, response.statusText);
      return NextResponse.json({ error: "Failed to generate article from OpenAI" }, { status: 500 });
    }

    const data = await response.json();
    console.log("OpenAI response:", data);

    if (!data.choices || data.choices.length === 0) {
      console.error("❌ No choices in OpenAI response");
      return NextResponse.json({ error: "No content returned from OpenAI" }, { status: 500 });
    }

    return NextResponse.json({ content: data.choices[0].message.content });  // Accessing content from the response
  } catch (error) {
    console.error("❌ Error in OpenAI request:", error);
    return NextResponse.json({ error: "Failed to generate article" }, { status: 500 });
  }
}